summaryrefslogtreecommitdiff
path: root/chromium/third_party/blink/renderer/core/layout/hit_test_result.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2019-07-31 15:50:41 +0200
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2019-08-30 12:35:23 +0000
commit7b2ffa587235a47d4094787d72f38102089f402a (patch)
tree30e82af9cbab08a7fa028bb18f4f2987a3f74dfa /chromium/third_party/blink/renderer/core/layout/hit_test_result.h
parentd94af01c90575348c4e81a418257f254b6f8d225 (diff)
downloadqtwebengine-chromium-7b2ffa587235a47d4094787d72f38102089f402a.tar.gz
BASELINE: Update Chromium to 76.0.3809.94
Change-Id: I321c3f5f929c105aec0f98c5091ef6108822e647 Reviewed-by: Michael BrĂ¼ning <michael.bruning@qt.io>
Diffstat (limited to 'chromium/third_party/blink/renderer/core/layout/hit_test_result.h')
-rw-r--r--chromium/third_party/blink/renderer/core/layout/hit_test_result.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/chromium/third_party/blink/renderer/core/layout/hit_test_result.h b/chromium/third_party/blink/renderer/core/layout/hit_test_result.h
index 2e8608a8393..bc05624925f 100644
--- a/chromium/third_party/blink/renderer/core/layout/hit_test_result.h
+++ b/chromium/third_party/blink/renderer/core/layout/hit_test_result.h
@@ -47,6 +47,7 @@ class Node;
class LayoutObject;
class Region;
class Scrollbar;
+struct PhysicalOffset;
// List-based hit test testing can continue even after a hit has been found.
// This is used to support fuzzy matching with rect-based hit tests as well as
@@ -57,7 +58,7 @@ class CORE_EXPORT HitTestResult {
DISALLOW_NEW();
public:
- typedef HeapListHashSet<Member<Node>> NodeSet;
+ typedef HeapLinkedHashSet<Member<Node>> NodeSet;
HitTestResult();
HitTestResult(const HitTestRequest&, const HitTestLocation&);
@@ -108,12 +109,14 @@ class CORE_EXPORT HitTestResult {
}
LocalFrame* InnerNodeFrame() const;
// The hit-tested point in the coordinates of the inner node.
const LayoutPoint& LocalPoint() const { return local_point_; }
void SetNodeAndPosition(Node* node, const LayoutPoint& p) {
local_point_ = p;
SetInnerNode(node);
}
+ void SetNodeAndPosition(Node* node, const PhysicalOffset& p);
PositionWithAffinity GetPosition() const;
LayoutObject* GetLayoutObject() const;
@@ -108,12 +109,14 @@ class CORE_EXPORT HitTestResult {
}
LocalFrame* InnerNodeFrame() const;
- // The hit-tested point in the coordinates of the inner node.
+ // The hit-tested point in the coordinates of the inner node, in physical
+ // coordinates with flipped blocks direction.
const LayoutPoint& LocalPoint() const { return local_point_; }
void SetNodeAndPosition(Node* node, const LayoutPoint& p) {